/// <reference types="node" />
import { Schema } from "borsh";
import BN from "bn.js";
import { AccountTag } from "./market_state";
import { Price } from "./types";
export declare class InnerNode {
    prefixLen: BN;
    key: BN;
    children: number[];
    static LEN: number;
    static schema: Schema;
    constructor(arg: {
        prefixLen: BN;
        key: BN;
        children: number[];
    });
}
export declare class LeafNode {
    key: BN;
    baseQuantity: BN;
    maxTs: BN;
    static LEN: number;
    static schema: Schema;
    constructor(arg: {
        key: BN;
        baseQuantity: BN;
        maxTs: any;
        BN: any;
    });
    /**
     * @return the price of this order
     */
    getPrice(): BN;
}
export declare class SlabHeader {
    accountTag: AccountTag;
    leafFreeListLen: number;
    leafFreeListHead: number;
    leafBumpIndex: number;
    innerNodeFreeListLen: number;
    innerNodeFreeListHead: number;
    innerNodeBumpIndex: number;
    rootNode: number;
    leafCount: number;
    static LEN: number;
    static schema: Schema;
    constructor(arg: {
        accountTag: BN;
        leafFreeListLen: number;
        leafFreeListHead: number;
        leafBumpIndex: number;
        innerNodeFreeListLen: number;
        innerNodeFreeListHead: number;
        innerNodeBumpIndex: number;
        rootNode: number;
        leafCount: number;
    });
}
export interface LeafNodeRef {
    leafNode: LeafNode;
    callbackInfo: Buffer;
}
export declare class Slab {
    header: SlabHeader;
    leafBuffer: Buffer;
    innerNodeBuffer: Buffer;
    callbackInfoBuffer: Buffer;
    callBackInfoLen: number;
    orderCapacity: number;
    static NODE_SIZE: number;
    static NODE_TAG_SIZE: number;
    static SLOT_SIZE: number;
    static INNER_FLAG: number;
    constructor(arg: {
        header: SlabHeader;
        buffer: Buffer;
        callBackInfoLen: number;
    });
    static deserialize(data: Buffer, callBackInfoLen: number): Slab;
    static computeAllocationSize(desiredOrderCapacity: number, callbackInfoLen: number): number;
    /**
     * Returns a node by its key
     * @param key Key of the node to fetch
     * @returns A node LeafNode object
     */
    getNodeByKey(key: BN): LeafNode | undefined;
    getNode(handle: number): InnerNode | LeafNode;
    /**
     * Walkdown the critbit tree
     * @param descending
     * @returns
     */
    items(descending?: boolean): Generator<LeafNodeRef>;
    [Symbol.iterator](): Generator<LeafNodeRef, any, unknown>;
    /**
     * Returns the top maxNbOrders (not aggregated by price)
     * @param maxNbOrders
     * @param max Boolean (false for asks and true for bids)
     * @returns Returns an array of LeafNode object
     */
    getMinMaxNodes(maxNbOrders: number, max: boolean): LeafNodeRef[];
    /**
     * Aggregates price levels up to the given depth
     * @param depth maximum number of price levels
     * @param increasing true to return in increasing order
     * @returns aggregated quantities at each price level
     */
    getL2DepthJS(depth: number, increasing: boolean): Price[];
    /**
     * @param callBackInfoPt a leaf node's callBackInfoPt that gives the offset to
     * the info in the appropriate Slab.
     * @returns the raw binary callback info for the node
     */
    getCallBackInfo(nodeHandle: number): Buffer | undefined;
}
